EXPORTS
	??0CPKCS7SignedObject@@IAE@XZ @ 1 NONAME ; CPKCS7SignedObject::CPKCS7SignedObject(void)
	??1CPKCS7SignedObject@@UAE@XZ @ 2 NONAME ; CPKCS7SignedObject::~CPKCS7SignedObject(void)
	?Certificate@CPKCS7ExtendedCertificateOrCertificate@@QBEABVCX509Certificate@@XZ @ 3 NONAME ; class CX509Certificate const & CPKCS7ExtendedCertificateOrCertificate::Certificate(void) const
	?Certificates@CPKCS7SignedObject@@QBEABV?$RPointerArray@VCPKCS7ExtendedCertificateOrCertificate@@@@XZ @ 4 NONAME ; class RPointerArray<class CPKCS7ExtendedCertificateOrCertificate> const & CPKCS7SignedObject::Certificates(void) const
	?ConstructL@CPKCS7SignedObject@@IAEXABVTDesC8@@@Z @ 5 NONAME ABSENT ; void CPKCS7SignedObject::ConstructL(class TDesC8 const &)
	?ContentData@CPKCS7ContentInfo@@QBEPBVTDesC8@@XZ @ 6 NONAME ABSENT ; class TDesC8 const * CPKCS7ContentInfo::ContentData(void) const
	?ContentInfo@CPKCS7SignedObject@@QBEABVCPKCS7ContentInfo@@XZ @ 7 NONAME ; class CPKCS7ContentInfo const & CPKCS7SignedObject::ContentInfo(void) const
	?ContentType@CPKCS7ContentInfo@@QBEHXZ @ 8 NONAME ABSENT ; int CPKCS7ContentInfo::ContentType(void) const
	?DataElementEncoding@CPKCS7SignedObject@@UBEPBVTPtrC8@@I@Z @ 9 NONAME ; class TPtrC8 const * CPKCS7SignedObject::DataElementEncoding(unsigned int) const
	?DigestAlgorithm@CPKCS7SignerInfo@@QBEABVCX509AlgorithmIdentifier@@XZ @ 10 NONAME ; class CX509AlgorithmIdentifier const & CPKCS7SignerInfo::DigestAlgorithm(void) const
	?DigestAlgorithms@CPKCS7SignedObject@@QBEABV?$RPointerArray@VCX509AlgorithmIdentifier@@@@XZ @ 11 NONAME ; class RPointerArray<class CX509AlgorithmIdentifier> const & CPKCS7SignedObject::DigestAlgorithms(void) const
	?DigestEncryptionAlgorithm@CPKCS7SignerInfo@@QBEABVCX509AlgorithmIdentifier@@XZ @ 12 NONAME ; class CX509AlgorithmIdentifier const & CPKCS7SignerInfo::DigestEncryptionAlgorithm(void) const
	?EncryptedDigest@CPKCS7SignerInfo@@QBE?BVTPtrC8@@XZ @ 13 NONAME ; class TPtrC8 const CPKCS7SignerInfo::EncryptedDigest(void) const
	?InternalizeL@CPKCS7SignedObject@@UAEXAAVRReadStream@@@Z @ 14 NONAME ; void CPKCS7SignedObject::InternalizeL(class RReadStream &)
	?IssuerAndSerialNumber@CPKCS7SignerInfo@@QBEABVCPKCS7IssuerAndSerialNumber@@XZ @ 15 NONAME ; class CPKCS7IssuerAndSerialNumber const & CPKCS7SignerInfo::IssuerAndSerialNumber(void) const
	?IssuerName@CPKCS7IssuerAndSerialNumber@@QBEABVCX500DistinguishedName@@XZ @ 16 NONAME ; class CX500DistinguishedName const & CPKCS7IssuerAndSerialNumber::IssuerName(void) const
	?NewL@CPKCS7SignedObject@@SAPAV1@ABVTDesC8@@@Z @ 17 NONAME ABSENT ; class CPKCS7SignedObject * CPKCS7SignedObject::NewL(class TDesC8 const &)
	?NewLC@CPKCS7SignedObject@@SAPAV1@ABVTDesC8@@@Z @ 18 NONAME ABSENT ; class CPKCS7SignedObject * CPKCS7SignedObject::NewLC(class TDesC8 const &)
	?SerialNumber@CPKCS7IssuerAndSerialNumber@@QBEABVTDesC8@@XZ @ 19 NONAME ; class TDesC8 const & CPKCS7IssuerAndSerialNumber::SerialNumber(void) const
	?SignedDataL@CPKCS7SignedObject@@UBE?BVTPtrC8@@XZ @ 20 NONAME ; class TPtrC8 const CPKCS7SignedObject::SignedDataL(void) const
	?SignerInfo@CPKCS7SignedObject@@QBEABV?$RPointerArray@VCPKCS7SignerInfo@@@@XZ @ 21 NONAME ; class RPointerArray<class CPKCS7SignerInfo> const & CPKCS7SignedObject::SignerInfo(void) const
	?ValidateSignerL@CPKCS7SignedObject@@QAEHABVCPKCS7SignerInfo@@AAPAVHBufC8@@@Z @ 22 NONAME ; int CPKCS7SignedObject::ValidateSignerL(class CPKCS7SignerInfo const &, class HBufC8 * &)
	?Version@CPKCS7SignedObject@@QBEHXZ @ 23 NONAME ; int CPKCS7SignedObject::Version(void) const
	?Version@CPKCS7SignerInfo@@QBEHXZ @ 24 NONAME ; int CPKCS7SignerInfo::Version(void) const
	?Algorithm@CPKCS7DigestInfo@@QBE?AW4TAlgorithmId@@XZ @ 25 NONAME ; enum TAlgorithmId CPKCS7DigestInfo::Algorithm(void) const
	?ConstructL@CPKCS7SignedObject@@IAEXABVCPKCS7ContentInfo@@@Z @ 26 NONAME ; void CPKCS7SignedObject::ConstructL(class CPKCS7ContentInfo const &)
	?ContentData@CPKCS7ContentInfo@@QBE?BVTPtrC8@@XZ @ 27 NONAME ; class TPtrC8 const CPKCS7ContentInfo::ContentData(void) const
	?ContentType@CPKCS7ContentInfo@@QBE?AW4TContentInfoType@1@XZ @ 28 NONAME ; enum CPKCS7ContentInfo::TContentInfoType CPKCS7ContentInfo::ContentType(void) const
	?ContentType@CPKCS7EncryptedDataObject@@QBE?AW4TContentType@1@XZ @ 29 NONAME ; enum CPKCS7EncryptedDataObject::TContentType CPKCS7EncryptedDataObject::ContentType(void) const
	?DecryptDataL@CPKCS7EncryptedDataObject@@QBEPAVHBufC8@@ABVTDesC16@@@Z @ 30 NONAME ; class HBufC8 * CPKCS7EncryptedDataObject::DecryptDataL(class TDesC16 const &) const
	?Digest@CPKCS7DigestInfo@@QBEABVTDesC8@@XZ @ 31 NONAME ; class TDesC8 const & CPKCS7DigestInfo::Digest(void) const
	?EncodedParams@CPKCS7DigestInfo@@QBEABVTPtrC8@@XZ @ 32 NONAME ; class TPtrC8 const & CPKCS7DigestInfo::EncodedParams(void) const
	?EncryptParams@CPKCS7EncryptedDataObject@@QBEABVCPBEncryptParms@@XZ @ 33 NONAME ; class CPBEncryptParms const & CPKCS7EncryptedDataObject::EncryptParams(void) const
	?EncryptedContentInfoData@CPKCS7EncryptedDataObject@@QBEABVTDesC8@@XZ @ 34 NONAME ; class TDesC8 const & CPKCS7EncryptedDataObject::EncryptedContentInfoData(void) const
	?NewL@CPKCS7ContentInfo@@SAPAV1@ABVTDesC8@@@Z @ 35 NONAME ; class CPKCS7ContentInfo * CPKCS7ContentInfo::NewL(class TDesC8 const &)
	?NewL@CPKCS7DigestInfo@@SAPAV1@ABVTDesC8@@@Z @ 36 NONAME ; class CPKCS7DigestInfo * CPKCS7DigestInfo::NewL(class TDesC8 const &)
	?NewL@CPKCS7EncryptedDataObject@@SAPAV1@ABVCPKCS7ContentInfo@@@Z @ 37 NONAME ; class CPKCS7EncryptedDataObject * CPKCS7EncryptedDataObject::NewL(class CPKCS7ContentInfo const &)
	?NewL@CPKCS7SignedObject@@SAPAV1@ABVCPKCS7ContentInfo@@@Z @ 38 NONAME ; class CPKCS7SignedObject * CPKCS7SignedObject::NewL(class CPKCS7ContentInfo const &)
	?NewLC@CPKCS7SignedObject@@SAPAV1@ABVCPKCS7ContentInfo@@@Z @ 39 NONAME ; class CPKCS7SignedObject * CPKCS7SignedObject::NewLC(class CPKCS7ContentInfo const &)
	?Version@CPKCS7EncryptedDataObject@@QBEHXZ @ 40 NONAME ; int CPKCS7EncryptedDataObject::Version(void) const
	??1CCmsContentInfo@@UAE@XZ @ 41 NONAME ; CCmsContentInfo::~CCmsContentInfo(void)
	??1CCmsSignedObject@@UAE@XZ @ 42 NONAME ; CCmsSignedObject::~CCmsSignedObject(void)
	??1CCmsSignerIdentifier@@UAE@XZ @ 43 NONAME ; CCmsSignerIdentifier::~CCmsSignerIdentifier(void)
	??1CPKCS7IssuerAndSerialNumber@@UAE@XZ @ 44 NONAME ; CPKCS7IssuerAndSerialNumber::~CPKCS7IssuerAndSerialNumber(void)
	?AddCertificateL@CCmsSignedObject@@QAEXABVCX509Certificate@@@Z @ 45 NONAME ; void CCmsSignedObject::AddCertificateL(class CX509Certificate const &)
	?AddCertificateL@CCmsSignedObject@@QAEXABVTDesC8@@W4TCertificateType@CCmsCertificateChoice@@@Z @ 46 NONAME ; void CCmsSignedObject::AddCertificateL(class TDesC8 const &, enum CCmsCertificateChoice::TCertificateType)
	?AttributeCertificate@CCmsCertificateChoice@@QBEPBVHBufC8@@XZ @ 47 NONAME ; class HBufC8 const * CCmsCertificateChoice::AttributeCertificate(void) const
	?Certificate@CCmsCertificateChoice@@QBEABVCX509Certificate@@XZ @ 48 NONAME ; class CX509Certificate const & CCmsCertificateChoice::Certificate(void) const
	?CertificateType@CCmsCertificateChoice@@QAE?AW4TCertificateType@1@XZ @ 49 NONAME ; enum CCmsCertificateChoice::TCertificateType CCmsCertificateChoice::CertificateType(void)
	?Certificates@CCmsSignedObject@@QBEABV?$RPointerArray@VCCmsCertificateChoice@@@@XZ @ 50 NONAME ; class RPointerArray<class CCmsCertificateChoice> const & CCmsSignedObject::Certificates(void) const
	?ContentData@CCmsContentInfo@@QBE?BVTPtrC8@@XZ @ 51 NONAME ; class TPtrC8 const CCmsContentInfo::ContentData(void) const
	?ContentData@CEncapsulatedContentInfo@@QBE?BVTPtrC8@@XZ @ 52 NONAME ; class TPtrC8 const CEncapsulatedContentInfo::ContentData(void) const
	?ContentInfo@CCmsSignedObject@@QBEABVCEncapsulatedContentInfo@@XZ @ 53 NONAME ; class CEncapsulatedContentInfo const & CCmsSignedObject::ContentInfo(void) const
	?ContentType@CCmsContentInfo@@QBE?AW4TCmsContentInfoType@@XZ @ 54 NONAME ; enum TCmsContentInfoType CCmsContentInfo::ContentType(void) const
	?ContentType@CEncapsulatedContentInfo@@QBE?AW4TCmsContentInfoType@@XZ @ 55 NONAME ; enum TCmsContentInfoType CEncapsulatedContentInfo::ContentType(void) const
	?DataElementEncoding@CCmsSignedObject@@UBEPBVTPtrC8@@I@Z @ 56 NONAME ; class TPtrC8 const * CCmsSignedObject::DataElementEncoding(unsigned int) const
	?DigestAlgorithm@CCmsSignerInfo@@QBEABVCX509AlgorithmIdentifier@@XZ @ 57 NONAME ; class CX509AlgorithmIdentifier const & CCmsSignerInfo::DigestAlgorithm(void) const
	?DigestAlgorithms@CCmsSignedObject@@QBEABV?$RPointerArray@VCX509AlgorithmIdentifier@@@@XZ @ 58 NONAME ; class RPointerArray<class CX509AlgorithmIdentifier> const & CCmsSignedObject::DigestAlgorithms(void) const
	?EncodeASN1DERLC@CCmsContentInfo@@QBEPAVCASN1EncSequence@@XZ @ 59 NONAME ; class CASN1EncSequence * CCmsContentInfo::EncodeASN1DERLC(void) const
	?EncodeASN1DERLC@CCmsSignedObject@@QBEPAVCASN1EncSequence@@XZ @ 60 NONAME ; class CASN1EncSequence * CCmsSignedObject::EncodeASN1DERLC(void) const
	?InternalizeL@CCmsSignedObject@@UAEXAAVRReadStream@@@Z @ 61 NONAME ; void CCmsSignedObject::InternalizeL(class RReadStream &)
	?IsCertificateRevocationListsPresent@CCmsSignedObject@@QBEHXZ @ 62 NONAME ; int CCmsSignedObject::IsCertificateRevocationListsPresent(void) const
	?IsCertificateSetPresent@CCmsSignedObject@@QBEHXZ @ 63 NONAME ; int CCmsSignedObject::IsCertificateSetPresent(void) const
	?IsContentDataPresent@CEncapsulatedContentInfo@@QBEHXZ @ 64 NONAME ; int CEncapsulatedContentInfo::IsContentDataPresent(void) const
	?IsSignedAttributesPresent@CCmsSignerInfo@@QBEHXZ @ 65 NONAME ; int CCmsSignerInfo::IsSignedAttributesPresent(void) const
	?IsUnsignedAttributesPresent@CCmsSignerInfo@@QBEHXZ @ 66 NONAME ; int CCmsSignerInfo::IsUnsignedAttributesPresent(void) const
	?IssuerAndSerialNumber@CCmsSignerIdentifier@@QBEPBVCPKCS7IssuerAndSerialNumber@@XZ @ 67 NONAME ; class CPKCS7IssuerAndSerialNumber const * CCmsSignerIdentifier::IssuerAndSerialNumber(void) const
	?NewL@CCmsContentInfo@@SAPAV1@ABVTDesC8@@@Z @ 68 NONAME ; class CCmsContentInfo * CCmsContentInfo::NewL(class TDesC8 const &)
	?NewL@CCmsContentInfo@@SAPAV1@W4TCmsContentInfoType@@ABVTDesC8@@@Z @ 69 NONAME ; class CCmsContentInfo * CCmsContentInfo::NewL(enum TCmsContentInfoType, class TDesC8 const &)
	?NewL@CCmsSignedObject@@SAPAV1@ABVCCmsContentInfo@@@Z @ 70 NONAME ; class CCmsSignedObject * CCmsSignedObject::NewL(class CCmsContentInfo const &)
	?NewL@CCmsSignedObject@@SAPAV1@W4TCmsContentInfoType@@ABVTDesC8@@W4TAlgorithmId@@ABVCDSAPrivateKey@@ABVCX509Certificate@@H@Z @ 71 NONAME ; class CCmsSignedObject * CCmsSignedObject::NewL(enum TCmsContentInfoType, class TDesC8 const &, enum TAlgorithmId, class CDSAPrivateKey const &, class CX509Certificate const &, int)
	?NewL@CCmsSignedObject@@SAPAV1@W4TCmsContentInfoType@@ABVTDesC8@@W4TAlgorithmId@@ABVCRSAPrivateKey@@ABVCX509Certificate@@H@Z @ 72 NONAME ; class CCmsSignedObject * CCmsSignedObject::NewL(enum TCmsContentInfoType, class TDesC8 const &, enum TAlgorithmId, class CRSAPrivateKey const &, class CX509Certificate const &, int)
	?NewL@CCmsSignedObject@@SAPAV1@W4TCmsContentInfoType@@HABVTDesC8@@@Z @ 73 NONAME ; class CCmsSignedObject * CCmsSignedObject::NewL(enum TCmsContentInfoType, int, class TDesC8 const &)
	?NewLC@CCmsContentInfo@@SAPAV1@ABVTDesC8@@@Z @ 74 NONAME ; class CCmsContentInfo * CCmsContentInfo::NewLC(class TDesC8 const &)
	?NewLC@CCmsContentInfo@@SAPAV1@W4TCmsContentInfoType@@ABVTDesC8@@@Z @ 75 NONAME ; class CCmsContentInfo * CCmsContentInfo::NewLC(enum TCmsContentInfoType, class TDesC8 const &)
	?NewLC@CCmsSignedObject@@SAPAV1@ABVCCmsContentInfo@@@Z @ 76 NONAME ; class CCmsSignedObject * CCmsSignedObject::NewLC(class CCmsContentInfo const &)
	?NewLC@CCmsSignedObject@@SAPAV1@W4TCmsContentInfoType@@ABVTDesC8@@W4TAlgorithmId@@ABVCDSAPrivateKey@@ABVCX509Certificate@@H@Z @ 77 NONAME ; class CCmsSignedObject * CCmsSignedObject::NewLC(enum TCmsContentInfoType, class TDesC8 const &, enum TAlgorithmId, class CDSAPrivateKey const &, class CX509Certificate const &, int)
	?NewLC@CCmsSignedObject@@SAPAV1@W4TCmsContentInfoType@@ABVTDesC8@@W4TAlgorithmId@@ABVCRSAPrivateKey@@ABVCX509Certificate@@H@Z @ 78 NONAME ; class CCmsSignedObject * CCmsSignedObject::NewLC(enum TCmsContentInfoType, class TDesC8 const &, enum TAlgorithmId, class CRSAPrivateKey const &, class CX509Certificate const &, int)
	?NewLC@CCmsSignedObject@@SAPAV1@W4TCmsContentInfoType@@HABVTDesC8@@@Z @ 79 NONAME ; class CCmsSignedObject * CCmsSignedObject::NewLC(enum TCmsContentInfoType, int, class TDesC8 const &)
	?SignL@CCmsSignedObject@@QAEXABVTDesC8@@W4TAlgorithmId@@ABVCDSAPrivateKey@@ABVCX509Certificate@@H@Z @ 80 NONAME ; void CCmsSignedObject::SignL(class TDesC8 const &, enum TAlgorithmId, class CDSAPrivateKey const &, class CX509Certificate const &, int)
	?SignL@CCmsSignedObject@@QAEXABVTDesC8@@W4TAlgorithmId@@ABVCRSAPrivateKey@@ABVCX509Certificate@@H@Z @ 81 NONAME ; void CCmsSignedObject::SignL(class TDesC8 const &, enum TAlgorithmId, class CRSAPrivateKey const &, class CX509Certificate const &, int)
	?SignatureAlgorithm@CCmsSignerInfo@@QBEABVCX509AlgorithmIdentifier@@XZ @ 82 NONAME ; class CX509AlgorithmIdentifier const & CCmsSignerInfo::SignatureAlgorithm(void) const
	?SignatureValue@CCmsSignerInfo@@QBE?BVTPtrC8@@XZ @ 83 NONAME ; class TPtrC8 const CCmsSignerInfo::SignatureValue(void) const
	?SignedDataL@CCmsSignedObject@@UBE?BVTPtrC8@@XZ @ 84 NONAME ; class TPtrC8 const CCmsSignedObject::SignedDataL(void) const
	?SignerIdentifier@CCmsSignerInfo@@QBEABVCCmsSignerIdentifier@@XZ @ 85 NONAME ; class CCmsSignerIdentifier const & CCmsSignerInfo::SignerIdentifier(void) const
	?SignerIdentifierType@CCmsSignerIdentifier@@QBEHXZ @ 86 NONAME ; int CCmsSignerIdentifier::SignerIdentifierType(void) const
	?SignerInfo@CCmsSignedObject@@QBEABV?$RPointerArray@VCCmsSignerInfo@@@@XZ @ 87 NONAME ; class RPointerArray<class CCmsSignerInfo> const & CCmsSignedObject::SignerInfo(void) const
	?SubjectKeyIdentifier@CCmsSignerIdentifier@@QBEABVTDesC8@@XZ @ 88 NONAME ; class TDesC8 const & CCmsSignerIdentifier::SubjectKeyIdentifier(void) const
	?ValidateSignerLC@CCmsSignedObject@@QAEHABVCCmsSignerInfo@@AAPAVHBufC8@@@Z @ 89 NONAME ; int CCmsSignedObject::ValidateSignerLC(class CCmsSignerInfo const &, class HBufC8 * &)
	?ValidateSignerLC@CCmsSignedObject@@QAEHABVCCmsSignerInfo@@AAPAVHBufC8@@HABVTDesC8@@@Z @ 90 NONAME ; int CCmsSignedObject::ValidateSignerLC(class CCmsSignerInfo const &, class HBufC8 * &, int, class TDesC8 const &)
	?ValidateSignerLC@CCmsSignedObject@@QAEHABVCCmsSignerInfo@@ABV?$RPointerArray@VCX509Certificate@@@@AAPAVHBufC8@@@Z @ 91 NONAME ; int CCmsSignedObject::ValidateSignerLC(class CCmsSignerInfo const &, class RPointerArray<class CX509Certificate> const &, class HBufC8 * &)
	?ValidateSignerLC@CCmsSignedObject@@QAEHABVCCmsSignerInfo@@ABV?$RPointerArray@VCX509Certificate@@@@AAPAVHBufC8@@HABVTDesC8@@@Z @ 92 NONAME ; int CCmsSignedObject::ValidateSignerLC(class CCmsSignerInfo const &, class RPointerArray<class CX509Certificate> const &, class HBufC8 * &, int, class TDesC8 const &)
	?Version@CCmsSignedObject@@QBEHXZ @ 93 NONAME ; int CCmsSignedObject::Version(void) const
	?Version@CCmsSignerInfo@@QBEHXZ @ 94 NONAME ; int CCmsSignerInfo::Version(void) const

